@@ -87,7 +87,6 @@ VALUE ox_sym_bank;  // Array
 
 VALUE ox_arg_error_class;
 VALUE ox_bag_clas;
-VALUE ox_bigdecimal_class;
 VALUE ox_cdata_clas;
 VALUE ox_comment_clas;
 VALUE ox_raw_clas;
@@ -1273,6 +1272,9 @@ static void parse_dump_options(VALUE ropts, Options copts) {
  * :strict
  *     - _:strict_ - raise an NotImplementedError if an undumpable object is encountered
  *     - _:tolerant_ - replaces undumplable objects with nil
+ *   - *:with_dtd* [true|false|nil] include DTD in the dump
+ *   - *:with_instruct* [true|false|nil] include instructions in the dump
+ *   - *:with_xml* [true|false|nil] include XML prolog in the dump
  *
  * Note that an indent of less than zero will result in a tight one line output
  * unless the text in the XML fields contain new line characters.
@@ -1310,6 +1312,9 @@ static VALUE dump(int argc, VALUE *argv, VALUE self) {
  * :strict
  *     - _:strict_ - raise an NotImplementedError if an undumpable object is encountered
  *     - _:tolerant_ - replaces undumplable objects with nil
+ *   - *:with_dtd* [true|false|nil] include DTD in the dump
+ *   - *:with_instruct* [true|false|nil] include instructions in the dump
+ *   - *:with_xml* [true|false|nil] include XML prolog in the dump
  *
  * Note that an indent of less than zero will result in a tight one line output
  * unless the text in the XML fields contain new line characters.
@@ -1331,6 +1336,9 @@ static VALUE to_xml(int argc, VALUE *argv, VALUE self) {
  * :strict
  *     - _:strict_ - raise an NotImplementedError if an undumpable object is encountered
  *     - _:tolerant_ - replaces undumplable objects with nil
+ *   - *:with_dtd* [true|false|nil] include DTD in the dump
+ *   - *:with_instruct* [true|false|nil] include instructions in the dump
+ *   - *:with_xml* [true|false|nil] include XML prolog in the dump
  *
  * Note that an indent of less than zero will result in a tight one line output
  * unless the text in the XML fields contain new line characters.
@@ -1363,7 +1371,7 @@ static VALUE cache8_test(VALUE self) {
 }
 #endif
 
-void Init_ox() {
+void Init_ox(void) {
 #if HAVE_RB_EXT_RACTOR_SAFE
     rb_ext_ractor_safe(true);
 #endif
@@ -1390,7 +1398,7 @@ void Init_ox() {
 
     rb_require("time");
     rb_require("date");
-    rb_require("bigdecimal");
+    // rb_require("bigdecimal");
     rb_require("stringio");
 
     ox_abort_id             = rb_intern("abort");
@@ -1462,7 +1470,6 @@ void Init_ox() {
     ox_arg_error_class    = rb_const_get_at(Ox, rb_intern("ArgError"));
     ox_struct_class       = rb_const_get(rb_cObject, rb_intern("Struct"));
     ox_stringio_class     = rb_const_get(rb_cObject, rb_intern("StringIO"));
-    ox_bigdecimal_class   = rb_const_get(rb_cObject, rb_intern("BigDecimal"));
 
     abort_sym = ID2SYM(rb_intern("abort"));
     rb_gc_register_address(&abort_sym);
@@ -1580,7 +1587,6 @@ void Init_ox() {
     rb_gc_register_address(&ox_arg_error_class);
     rb_gc_register_address(&ox_bag_clas);
     rb_gc_register_address(&ox_bag_clas);
-    rb_gc_register_address(&ox_bigdecimal_class);
     rb_gc_register_address(&ox_cdata_clas);
     rb_gc_register_address(&ox_cdata_clas);
     rb_gc_register_address(&ox_comment_clas);
