@@ -18,6 +18,7 @@
 #include "ruby.h"
 #include "special.h"
 
+static void  mark_pi_cb(void *ptr);
 static void  read_instruction(PInfo pi);
 static void  read_doctype(PInfo pi);
 static void  read_comment(PInfo pi);
@@ -33,6 +34,17 @@ static char *read_coded_chars(PInfo pi, char *text);
 static void  next_non_white(PInfo pi);
 static int   collapse_special(PInfo pi, char *str);
 
+static const rb_data_type_t ox_wrap_type = {
+    "Object",
+    {
+        mark_pi_cb,
+        NULL,
+        NULL,
+    },
+    0,
+    0,
+};
+
 /* This XML parser is a single pass, destructive, callback parser. It is a
  * single pass parse since it only make one pass over the characters in the
  * XML document string. It is destructive because it re-uses the content of
@@ -140,7 +152,7 @@ ox_parse(char *xml, size_t len, ParseCallbacks pcb, char **endp, Options options
     // initialize parse info
     helper_stack_init(&pi.helpers);
     // Protect against GC
-    wrap = Data_Wrap_Struct(rb_cObject, mark_pi_cb, NULL, &pi);
+    wrap = TypedData_Wrap_Struct(rb_cObject, &ox_wrap_type, &pi);
 
     err_init(&pi.err);
     pi.str        = xml;
@@ -167,7 +179,7 @@ ox_parse(char *xml, size_t len, ParseCallbacks pcb, char **endp, Options options
             helper_stack_cleanup(&pi.helpers);
             return Qnil;
         }
-        pi.s++;    // past <
+        pi.s++;  // past <
         switch (*pi.s) {
         case '?':  // processing instruction
             pi.s++;
@@ -330,6 +342,15 @@ DONE:
         } else {
             pi->pcb->instruct(pi, target, attrs.head, content_ptr);
         }
+    } else {
+        for (Attr a = attrs.head; a < attrs.tail; a++) {
+            if (0 == strcasecmp(a->name, "encoding")) {
+                strncpy(pi->options->encoding, a->value, sizeof(pi->options->encoding) - 1);
+                pi->options->encoding[sizeof(pi->options->encoding) - 1] = '\0';
+                pi->options->rb_enc                                      = rb_enc_find(a->value);
+                break;
+            }
+        }
     }
     attr_stack_cleanup(&attrs);
     if (content_ptr != content) {
@@ -671,8 +692,12 @@ static char *read_element(PInfo pi) {
                     break;
                 }
             } else { /* read as TEXT */
+                char prev = *(start - 1);
+
                 pi->s = start;
-                /*pi->s--; */
+                if ('>' != prev && (' ' <= prev || is_white(prev))) {
+                    pi->s--;
+                }
                 read_text(pi);
                 /*read_reduced_text(pi); */
 
