@@ -62,6 +62,17 @@ static Nv   hint_try_close(SaxDrive dr, const char *name);
 
 VALUE ox_sax_value_class = Qnil;
 
+const rb_data_type_t ox_sax_value_type = {
+    "Ox/Sax/Value",
+    {
+        NULL,
+        NULL,
+        NULL,
+    },
+    0,
+    0,
+};
+
 static VALUE protect_parse(VALUE drp) {
     parse((SaxDrive)drp);
 
@@ -256,7 +267,7 @@ static void sax_drive_init(SaxDrive dr, VALUE handler, VALUE io, SaxOptions opti
     dr->buf.dr = dr;
     stack_init(&dr->stack);
     dr->handler   = handler;
-    dr->value_obj = Data_Wrap_Struct(ox_sax_value_class, 0, 0, dr);
+    dr->value_obj = TypedData_Wrap_Struct(ox_sax_value_class, &ox_sax_value_type, dr);
     rb_gc_register_address(&dr->value_obj);
     dr->options = *options;
     dr->err     = 0;
@@ -984,7 +995,11 @@ static char read_element_end(SaxDrive dr) {
             } else {
                 snprintf(msg, sizeof(msg) - 1, "%selement '%s' closed but not opened", EL_MISMATCH, dr->buf.str);
                 ox_sax_drive_error_at(dr, msg, pos, line, col);
-                name = str2sym(dr, dr->buf.str, dr->buf.tail - dr->buf.str - 2, 0);
+                if ('\x00' == *dr->buf.tail) {
+                    name = str2sym(dr, dr->buf.str, dr->buf.tail - dr->buf.str - 1, 0);
+                } else {
+                    name = str2sym(dr, dr->buf.str, dr->buf.tail - dr->buf.str - 2, 0);
+                }
                 if (dr->has_start_element && 0 >= dr->blocked &&
                     (NULL == h || ActiveOverlay == h->overlay || NestOverlay == h->overlay)) {
                     VALUE args[1];
@@ -1219,7 +1234,7 @@ static char read_attrs(SaxDrive dr, char c, char termc, char term2, int is_xml,
             c = buf_next_non_white(&dr->buf);
         }
         if ('=' != c) {
-	    // TBD allow in smart mode
+            // TBD allow in smart mode
             if (eq_req) {
                 dr->err = 1;
                 return c;
@@ -1328,7 +1343,7 @@ static char read_quoted_value(SaxDrive dr, bool inst) {
     dr->buf.str = dr->buf.tail - 1;
     // TBD if smart or html then no error
     if (!(dr->options.smart && ox_hints_html() != dr->options.hints)) {
-	ox_sax_drive_error(dr, WRONG_CHAR "attribute value not in quotes");
+        ox_sax_drive_error(dr, WRONG_CHAR "attribute value not in quotes");
     }
     while ('\0' != (c = buf_get(&dr->buf))) {
         switch (c) {
@@ -1341,12 +1356,12 @@ static char read_quoted_value(SaxDrive dr, bool inst) {
             *(dr->buf.tail - 1) = '\0'; /* terminate value */
             // dr->buf.tail is in the correct position, one after the word terminator
             return c;
-        case '?':  // for instructions
-	    if (inst) {
-		*(dr->buf.tail - 1) = '\0'; /* terminate value */
-		return c;
-	    }
-	    break;
+        case '?':
+            if (inst) {
+                *(dr->buf.tail - 1) = '\0'; /* terminate value */
+                return c;
+            }
+            break;
         default: break;
         }
     }
