@@ -79,7 +79,7 @@ module Ox
     # - +other+ [Object] Object compare _self_ to.
     # *return* [Boolean] true if both Objects are equivalent, otherwise false.
     def eql?(other)
-      return false unless super(other)
+      return false unless super
       return false unless attributes == other.attributes
       return false unless nodes == other.nodes
 
@@ -100,7 +100,11 @@ module Ox
     def replace_text(txt)
       raise 'the argument to replace_text() must be a String' unless txt.is_a?(String)
 
-      @nodes.clear
+      if !instance_variable_defined?(:@nodes) or @nodes.nil?
+        @node = []
+      else
+        @nodes.clear
+      end
       @nodes << txt
     end
 
