@@ -1,7 +1,6 @@
 require 'handlers'
 
 module SaxTestHelpers
-
   # A helper method to initiate a sax parsing using a specified xml
   # structure as input, an expected stack of calls, a handler class
   # and an optional options hash to pass to the parser.
@@ -17,12 +16,12 @@ module SaxTestHelpers
   #                ], AllSax, :convert_special => true, :smart => true)
   #
   def parse_compare(xml, expected, handler_class = AllSax, opts = {}, handler_attr = :calls)
-    handler = handler_class.new()
+    handler = handler_class.new
     input = StringIO.new(xml)
     options = {
-      :symbolize => true,
-      #:convert_special => true,
-      :smart => false
+      symbolize: true,
+      # :convert_special => true,
+      smart: false
     }.merge(opts)
 
     Ox.sax_parse(handler, input, options)
@@ -30,11 +29,9 @@ module SaxTestHelpers
     actual = handler.send(handler_attr)
 
     if expected != actual
-      expected.each_index { |i|
-	if expected[i] != actual[i]
-	  puts "#{i}: #{expected[i]} != #{actual[i]}"
-	end
-      }
+      expected.each_index do |i|
+        puts "#{i}: #{expected[i]} != #{actual[i]}" if expected[i] != actual[i]
+      end
     end
     puts "\nexpected: #{expected}\n  actual: #{actual}" if expected != actual
     assert_equal(expected, actual)
