@@ -434,6 +434,26 @@ encoding = "UTF-8" ?>},
                   ])
   end
 
+  def test_sax_last_element_closed_not_opened
+    Ox.default_options = $ox_sax_options
+    parse_compare(%{</top>},
+                  [
+                    [:error, "Start End Mismatch: element 'top' closed but not opened", 1, 1],
+                    [:start_element, :top],
+                    [:end_element, :top]
+                  ])
+  end
+
+  def test_sax_last_unnamed_element_closed_not_opened
+    Ox.default_options = $ox_sax_options
+    parse_compare(%{</>},
+                  [
+                    [:error, "Start End Mismatch: element '' closed but not opened", 1, 1],
+                    [:start_element, :''],
+                    [:end_element, :'']
+                  ])
+  end
+
   def test_sax_empty_element
     Ox.default_options = $ox_sax_options
     parse_compare(%{  <top>  </top>},
@@ -1436,11 +1456,10 @@ this is not part of the xml document
                    [:start_element, :html],
                    [:attr, :lang, 'en'],
                    [:start_element, :head],
-                   [:attr, :url, "http://ohler.com?x=2"],
-                   [:text, " "],
+                   [:attr, :url, 'http://ohler.com?x=2'],
+                   [:text, ' '],
                    [:end_element, :head],
-                   [:end_element, :html],
+                   [:end_element, :html]
                  ], handler.calls)
   end
-
 end
