@@ -3,6 +3,8 @@
 # required. That can be set in the RUBYOPT environment variable.
 # export RUBYOPT=-w
 
+# frozen_string_literal: true
+
 $VERBOSE = true
 
 $: << File.join(File.dirname(__FILE__), '../lib')
@@ -836,9 +838,6 @@ class Func < Test::Unit::TestCase
       a << e
       a << b
       loaded = dump_and_load(b, false, true)
-      # modify the string
-      loaded.instance_variable_get(:@s).gsub!(',', '_')
-      b.instance_variable_get(:@s).gsub!(',', '_')
       # modify hash
       loaded.instance_variable_get(:@h)[1] = 3
       b.instance_variable_get(:@h)[1] = 3
@@ -938,6 +937,15 @@ class Func < Test::Unit::TestCase
     assert_equal(xml, dumped)
   end
 
+  def test_full_encoding_mode_hash
+    Ox.default_options = $ox_generic_options
+    xml = %{<?xml version="1.0" encoding="UTF-8"?>
+<いち name="ピーター" つま="まきえ">ピーター</いち>
+}
+    obj = Ox.load(xml, mode: :hash)
+    assert_equal(obj, { :いち => [{ :name => 'ピーター', :つま => 'まきえ' }, 'ピーター'] })
+  end
+
   def test_obj_encoding
     Ox.default_options = $ox_object_options
     if RUBY_VERSION.start_with?('1.8')
@@ -1906,7 +1914,8 @@ comment -->
 
   def test_encoding_ascii
     Ox.default_options = $ox_generic_options
-    xml = '<?xml version="1.0" encoding="UTF-8" ?><text>H&#233;ra&#239;dios</text>'.force_encoding(Encoding::ASCII_8BIT)
+    xml = '<?xml version="1.0" encoding="UTF-8" ?><text>H&#233;ra&#239;dios</text>'.dup
+    xml.force_encoding(Encoding::ASCII_8BIT)
     text = Ox.load(xml).root.text
     assert_equal('Héraïdios', text)
     assert_equal(Encoding::UTF_8, text.encoding)
@@ -1923,6 +1932,13 @@ comment -->
     end
     loaded
   end
+
+  def test_limit_encoding
+    Ox.default_options = $ox_object_options
+    xml = '<?xml version="1.0" encoding="UTF-8"?><doc><name>Martin</name></doc>'.encode('ASCII-8BIT')
+    enc = Ox.load(xml, mode: :limited).locate('name').first.text.encoding
+    assert_equal('UTF-8', enc.to_s)
+  end
 end
 
 class Bag
