@@ -1,4 +1,3 @@
-
 require 'time'
 require 'libxml'
 
@@ -9,13 +8,13 @@ module Weather
     attr_accessor :highs
 
     def self.parse(filename, as_time)
-      handler = self.new(as_time)
+      handler = new(as_time)
       input = IO.open(IO.sysopen(filename))
       parser = LibXML::XML::SaxParser.io(input)
       parser.callbacks = handler
       parser.parse
       input.close
-      #puts handler.highs
+      # puts handler.highs
       handler.highs
     end
 
@@ -40,23 +39,23 @@ module Weather
     def on_characters(chars)
       chars.strip!
       return if chars.empty?
-      if 1 < @row
-        case @cell
-        when 2
-          if @as_time
-            @time = Time.parse(chars)
-          else
-            @time = chars
-          end
-        when 4
-          @highs[@time] = chars.to_f
+
+      return unless 1 < @row
+
+      case @cell
+      when 2
+        if @as_time
+          @time = Time.parse(chars)
+        else
+          @time = chars
         end
+      when 4
+        @highs[@time] = chars.to_f
       end
     end
 
     def on_error(msg)
       puts msg
     end
-
   end # WLxSax
 end # Weather
